pub enum Error {
    ChannelSend,
    ChannelRecv,
    EventFd(Error),
    Epoll(Error),
    FdAlreadyRegistered,
    InvalidId,
    InvalidCapacity,
}
Error conditions that may appear during EventManager related operations.

Variants

ChannelSend

Cannot send message on channel.

ChannelRecv

Cannot receive message on channel.

EventFd(Error)

Operation on eventfd failed.

Epoll(Error)

Operation on libc::epoll failed.

FdAlreadyRegistered

The fd is already associated with an existing subscriber.

InvalidId

The Subscriber ID does not exist or is no longer associated with a Subscriber.

InvalidCapacity

The ready list capacity passed to EventManager::new is invalid.