pub struct EpollManager {
    pub mgr: Arc<Mutex<EventManager<EpollSubscriber>>>,
    /* private fields */
}
A wrapper struct over EventManager to solve possible deadlock.

It’s a rather tough topic to deal with the epoll event manager in rust way. The event_manager::EventManager is designed for single-threaded environment and it leaves the task for concurrent access to the clients. There are two types of threads involved, epoll worker thread and vCPU threads. To reduce overhead, the epoll worker thread calls epoll::wait() without timeout, so the worker thread will hold the EpollManagerImpl::Mutex for undetermined periods. When the vCPU threads tries to activate virtio devices, they need to acquire the same EpollManagerImpl::Mutex. Thus the vCPU threads may block for an undetermined time. To solve this issue, we perform an kick()/try_lock() loop to wake up the epoll worker thread from sleeping.

Fields

mgr: Arc<Mutex<EventManager<EpollSubscriber>>>

Implementations

Add a new epoll event subscriber.

Remove a given epoll event subscriber.

Add an epoll event to be monitored.

Run the epoll polling loop.