pub struct RemoteEndpoint<S> { /* private fields */ }
Enables interactions with an EventManager that runs on a different thread of execution.

Implementations

Call the specified closure on the associated remote EventManager (provided as a SubscriberOps trait object), and return the result. This method blocks until the result is received, and calling it from the same thread where the event loop runs leads to a deadlock.

Call the specified closure on the associated local/remote EventManager (provided as a SubscriberOps trait object), and discard the result. This method only fires the request but does not wait for result, so it may be called from the same thread where the event loop runs.

Kick the worker thread to wake up from the epoll event loop.