Trait dbs_utils::epoll_manager::MutEventSubscriber
source · [−]pub trait MutEventSubscriber {
fn process(&mut self, events: Events, ops: &mut EventOps<'_>);
fn init(&mut self, ops: &mut EventOps<'_>);
}Expand description
Allows the interaction between an EventManager and different event subscribers. Methods
are invoked with a mutable self borrow.
Required Methods
Process events triggered in the event manager loop.
Optionally, the subscriber can use ops to update the events it monitors.
Initialization called by the EventManager when the subscriber is registered.
The subscriber is expected to use ops to register the events it wants to monitor.