pub struct Tap {
pub tap_file: File,
/* private fields */
}Expand description
Handle for a network tap interface.
For now, this simply wraps the file descriptor for the tap device so methods can run ioctls on the interface. The tap interface fd will be closed when Tap goes out of scope, and the kernel will clean up the interface automatically.
Fields
tap_file: Filetap device file handle
Implementations
sourceimpl Tap
impl Tap
sourceimpl Tap
impl Tap
sourcepub fn into_mq_taps(self, vq_pairs: usize) -> Result<Vec<Tap>, Error>
pub fn into_mq_taps(self, vq_pairs: usize) -> Result<Vec<Tap>, Error>
Change the origin tap into multiqueue taps.
sourcepub fn set_offload(&self, flags: c_uint) -> Result<(), Error>
pub fn set_offload(&self, flags: c_uint) -> Result<(), Error>
Set the offload flags for the tap interface.