Struct dbs_utils::metric::SharedStoreMetric
source · [−]pub struct SharedStoreMetric(_);Expand description
Representation of a metric that is expected to hold a value that can be accessed from more than one thread, so more synchronization is necessary.