pub struct TokenBucket { /* private fields */ }
TokenBucket provides a lower level interface to rate limiting with a configurable capacity, refill-rate and initial burst.

Implementations

Creates a TokenBucket wrapped in an Option.

TokenBucket created is of size total capacity and takes complete_refill_time_ms milliseconds to go from zero tokens to total capacity. The one_time_burst is initial extra credit on top of total capacity, that does not replenish and which can be used for an initial burst of data.

If the size or the complete refill time are zero, then None is returned.

Attempts to consume tokens from the bucket and returns whether the action succeeded.

“Manually” adds tokens to bucket.

Returns the capacity of the token bucket.

Returns the remaining one time burst budget.

Returns the time in milliseconds required to to completely fill the bucket.

Returns the current budget (one time burst allowance notwithstanding).

Returns the initially configured one time burst budget.