Struct dbs_utils::rate_limiter::TokenBucket
source · [−]pub struct TokenBucket { /* private fields */ }Expand description
TokenBucket provides a lower level interface to rate limiting with a configurable capacity, refill-rate and initial burst.
Implementations
sourceimpl TokenBucket
impl TokenBucket
sourcepub fn new(size: u64, one_time_burst: u64, complete_refill_time_ms: u64) -> Self
pub fn new(size: u64, one_time_burst: u64, complete_refill_time_ms: u64) -> Self
Creates a TokenBucket wrapped in an Option.
TokenBucket created is of size total capacity and takes complete_refill_time_ms
milliseconds to go from zero tokens to total capacity. The one_time_burst is initial
extra credit on top of total capacity, that does not replenish and which can be used
for an initial burst of data.
If the size or the complete refill time are zero, then None is returned.
sourcepub fn reduce(&mut self, tokens: u64) -> BucketReduction
pub fn reduce(&mut self, tokens: u64) -> BucketReduction
Attempts to consume tokens from the bucket and returns whether the action succeeded.
sourcepub fn force_replenish(&mut self, tokens: u64)
pub fn force_replenish(&mut self, tokens: u64)
“Manually” adds tokens to bucket.
sourcepub fn one_time_burst(&self) -> u64
pub fn one_time_burst(&self) -> u64
Returns the remaining one time burst budget.
sourcepub fn refill_time_ms(&self) -> u64
pub fn refill_time_ms(&self) -> u64
Returns the time in milliseconds required to to completely fill the bucket.
sourcepub fn budget(&self) -> u64
pub fn budget(&self) -> u64
Returns the current budget (one time burst allowance notwithstanding).
sourcepub fn initial_one_time_burst(&self) -> u64
pub fn initial_one_time_burst(&self) -> u64
Returns the initially configured one time burst budget.