Structs

Structure representing the date in local time with nanosecond precision.

Holds a micro-second resolution timestamp with both the real time and cpu time.

Enums

Wrapper over libc::clockid_t to specify Linux Kernel clock source.

Constants

Constant to convert milliseconds to nanoseconds.

Constant to convert seconds to nanoseconds.

Functions

Returns a timestamp in milliseconds based on the provided clock type.

Returns a timestamp in nanoseconds based on the provided clock type.

Returns a timestamp in microseconds based on the provided clock type.

Get process CPU time in us.

Converts a timestamp in seconds to an equivalent one in nanoseconds. Returns None if the conversion overflows.

Returns a timestamp in nanoseconds from a monotonic clock.